==> ejc-mdm-impl-3.0.0-20220622.120916-82-sources.jar: com/ejianc/foundation/mdm/controller/sync/vo/ZzyjJobVO.java <==
package com.ejianc.foundation.mdm.controller.sync.vo;

import java.io.Serializable;

import org.apache.commons.lang3.StringUtils;

import com.alibaba.fastjson.JSONObject;

public class ZzyjJobVO implements Serializable {

	private static final long serialVersionUID = 1L;
	
	private String userid; //人员身份证号
	
	private String e0911; //兼职单位
	
	private String e0902; //兼职部门
	
	private String a0902; //兼职所属岗位序列
	
	private String e0907; //兼职时间

	private String createtime; //创建时间

	public String getE0911() {
		return e0911;
	}

	public void setE0911(String e0911) {
		this.e0911 = e0911;
	}

	public String getE0902() {
		return e0902;
	}

	public void setE0902(String e0902) {
		this.e0902 = e0902;
	}

	public String getA0902() {
		return a0902;
	}

	public void setA0902(String a0902) {
		this.a0902 = a0902;
	}

	public String getE0907() {
		return e0907;
	}

	public void setE0907(String e0907) {
		this.e0907 = e0907;
	}

	public String getCreatetime() {
		return createtime;
	}

	public void setCreatetime(String createtime) {
		this.createtime = createtime;
	}
	
	public String getUserid() {
		return userid;
	}

	public void setUserid(String userid) {
		this.userid = userid;
	}

	public JSONObject toJobVO() {
		JSONObject jobObject = new JSONObject();
		jobObject.put("orgId", e0911);
		jobObject.put("deptId", e0902);
		jobObject.put("postId", a0902);
		jobObject.put("userid", userid);
		if(StringUtils.isBlank(e0907)) {
			jobObject.put("jobStartTime", createtime);
		}else{
			jobObject.put("jobStartTime", e0907);
		}
		return jobObject;
	}
}

==> ejc-mdm-impl-3.0.0-20230815.010621-135-sources.jar: com/ejianc/foundation/mdm/controller/sync/vo/ZzyjJobVO.java <==
package com.ejianc.foundation.mdm.controller.sync.vo;

import java.io.Serializable;

import org.apache.commons.lang3.StringUtils;

import com.alibaba.fastjson.JSONObject;

public class ZzyjJobVO implements Serializable {

	private static final long serialVersionUID = 1L;
	
	private String userid; //人员身份证号
	
	private String e0911; //兼职单位
	
	private String e0902; //兼职部门

	private String a0902; //兼职所属岗位序列

	private String a0904; //兼职人员经历
	
	private String e0907; //兼职时间

	private String createtime; //创建时间

	public String getE0911() {
		return e0911;
	}

	public void setE0911(String e0911) {
		this.e0911 = e0911;
	}

	public String getE0902() {
		return e0902;
	}

	public void setE0902(String e0902) {
		this.e0902 = e0902;
	}

	public String getA0902() {
		return a0902;
	}

	public void setA0902(String a0902) {
		this.a0902 = a0902;
	}

	public String getE0907() {
		return e0907;
	}

	public void setE0907(String e0907) {
		this.e0907 = e0907;
	}

	public String getCreatetime() {
		return createtime;
	}

	public void setCreatetime(String createtime) {
		this.createtime = createtime;
	}
	
	public String getUserid() {
		return userid;
	}

	public void setUserid(String userid) {
		this.userid = userid;
	}

	public String getA0904() {
		return a0904;
	}

	public void setA0904(String a0904) {
		this.a0904 = a0904;
	}

	public JSONObject toJobVO() {
		JSONObject jobObject = new JSONObject();
		jobObject.put("orgId", e0911);
		jobObject.put("deptId", e0902);
		jobObject.put("postId", a0902);
		jobObject.put("userid", userid);
		if(StringUtils.isBlank(e0907)) {
			jobObject.put("jobStartTime", createtime);
		}else{
			jobObject.put("jobStartTime", e0907);
		}
		return jobObject;
	}
}
